==> c3dr_0.1.5.tar.gz: c3dr/tests/testthat/_snaps/read.md <==
# parameter import works

    Code
      d$parameters
    Output
      $POINT
      $POINT$USED
      [1] 55
      
      $POINT$SCALE
      [1] -0.07623225
      
      $POINT$RATE
      [1] 200
      
      $POINT$DATA_START
      [1] 29
      
      $POINT$FRAMES
      [1] 340
      
      $POINT$LABELS
       [1] "L_IAS"   "L_IPS"   "R_IPS"   "R_IAS"   "SNJ"     "SXS"     "TV8"    
       [8] "CV7"     "R_SCAP"  "L_HDF"   "L_HDB"   "R_HDB"   "R_HDF"   "L_FTC"  
      [15] "L_WAND1" "L_FLE"   "L_FME"   "L_FAX"   "L_TTC"   "L_WAND2" "L_FAL"  
      [22] "L_TAM"   "L_FCC"   "L_FM1"   "L_FM5"   "R_FTC"   "R_WAND1" "R_FLE"  
      [29] "R_FME"   "R_FAX"   "R_TTC"   "R_WAND2" "R_FAL"   "R_TAM"   "R_FCC"  
      [36] "R_FM1"   "R_FM5"   "L_HM5"   "L_HM2"   "L_UHE"   "L_RSP"   "L_WAND4"
      [43] "L_HLE"   "L_HME"   "L_WAND3" "R_HM5"   "R_HM2"   "R_UHE"   "R_RSP"  
      [50] "R_WAND4" "R_HLE"   "R_HME"   "R_WAND3" "L_SAJ"   "R_SAJ"  
      
      $POINT$DESCRIPTIONS
       [1] "L_IAS"   "L_IPS"   "R_IPS"   "R_IAS"   "SNJ"     "SXS"     "TV8"    
       [8] "CV7"     "R_SCAP"  "L_HDF"   "L_HDB"   "R_HDB"   "R_HDF"   "L_FTC"  
      [15] "L_WAND1" "L_FLE"   "L_FME"   "L_FAX"   "L_TTC"   "L_WAND2" "L_FAL"  
      [22] "L_TAM"   "L_FCC"   "L_FM1"   "L_FM5"   "R_FTC"   "R_WAND1" "R_FLE"  
      [29] "R_FME"   "R_FAX"   "R_TTC"   "R_WAND2" "R_FAL"   "R_TAM"   "R_FCC"  
      [36] "R_FM1"   "R_FM5"   "L_HM5"   "L_HM2"   "L_UHE"   "L_RSP"   "L_WAND4"
      [43] "L_HLE"   "L_HME"   "L_WAND3" "R_HM5"   "R_HM2"   "R_UHE"   "R_RSP"  
      [50] "R_WAND4" "R_HLE"   "R_HME"   "R_WAND3" "L_SAJ"   "R_SAJ"  
      
      $POINT$UNITS
      [1] "mm"
      
      $POINT$LONG_FRAMES
      [1] 340
      
      $POINT$Y_SCREEN
      [1] "-Z"
      
      $POINT$X_SCREEN
      [1] "-X"
      
      $POINT$ORIGINAL_LAST_FRAME
      [1] 1631
      
      
      $ANALOG
      $ANALOG$USED
      [1] 69
      
      $ANALOG$LABELS
       [1] "FP1_FX"                       "FP1_FY"                      
       [3] "FP1_FZ"                       "FP1_MX"                      
       [5] "FP1_MY"                       "FP1_MZ"                      
       [7] "Nothing"                      "Channel_08"                  
       [9] "Channel_09"                   "Channel_10"                  
      [11] "PF2-FX"                       "PF2-FY"                      
      [13] "PF2-FZ"                       "PF2-MX"                      
      [15] "PF2-MY"                       "PF2-MZ"                      
      [17] "Channel_17"                   "Channel_18"                  
      [19] "Channel_19"                   "Channel_20"                  
      [21] "Channel_21"                   "Channel_22"                  
      [23] "Channel_23"                   "Channel_24"                  
      [25] "Channel_25"                   "Channel_26"                  
      [27] "Channel_27"                   "Channel_28"                  
      [29] "Channel_29"                   "Channel_30"                  
      [31] "Channel_31"                   "Channel_32"                  
      [33] "TAPIS FZ1"                    "TAPIS FZ2"                   
      [35] "TAPIS FZ3"                    "TAPIS FZ4"                   
      [37] "TAPIS FY1+4"                  "TAPIS FY2+3"                 
      [39] "TAPIS FX1+2"                  "TAPIS FX3+4"                 
      [41] "EMG 1"                        "EMG 2"                       
      [43] "EMG 3"                        "EMG 4"                       
      [45] "EMG 5"                        "EMG 6"                       
      [47] "EMG 7"                        "EMG 8"                       
      [49] "EMG 9"                        "EMG 10"                      
      [51] "EMG 11"                       "EMG 12"                      
      [53] "EMG 13"                       "EMG 14"                      
      [55] "EMG 15"                       "EMG 16"                      
      [57] "Sync"                         "Amti Gen 5 OR6-5-1000 3581_1"
      [59] "Amti Gen 5 OR6-5-1000 3581_2" "Amti Gen 5 OR6-5-1000 3581_3"
      [61] "Amti Gen 5 OR6-5-1000 3581_4" "Amti Gen 5 OR6-5-1000 3581_5"
      [63] "Amti Gen 5 OR6-5-1000 3581_6" "Amti Gen 5 OR6-5-1000 3582_1"
      [65] "Amti Gen 5 OR6-5-1000 3582_2" "Amti Gen 5 OR6-5-1000 3582_3"
      [67] "Amti Gen 5 OR6-5-1000 3582_4" "Amti Gen 5 OR6-5-1000 3582_5"
      [69] "Amti Gen 5 OR6-5-1000 3582_6"
      
      $ANALOG$DESCRIPTIONS
       [1] "FP1_FX"                       "FP1_FY"                      
       [3] "FP1_FZ"                       "FP1_MX"                      
       [5] "FP1_MY"                       "FP1_MZ"                      
       [7] "Nothing"                      "Channel_08"                  
       [9] "Channel_09"                   "Channel_10"                  
      [11] "PF2-FX"                       "PF2-FY"                      
      [13] "PF2-FZ"                       "PF2-MX"                      
      [15] "PF2-MY"                       "PF2-MZ"                      
      [17] "Channel_17"                   "Channel_18"                  
      [19] "Channel_19"                   "Channel_20"                  
      [21] "Channel_21"                   "Channel_22"                  
      [23] "Channel_23"                   "Channel_24"                  
      [25] "Channel_25"                   "Channel_26"                  
      [27] "Channel_27"                   "Channel_28"                  
      [29] "Channel_29"                   "Channel_30"                  
      [31] "Channel_31"                   "Channel_32"                  
      [33] "TAPIS FZ1"                    "TAPIS FZ2"                   
      [35] "TAPIS FZ3"                    "TAPIS FZ4"                   
      [37] "TAPIS FY1+4"                  "TAPIS FY2+3"                 
      [39] "TAPIS FX1+2"                  "TAPIS FX3+4"                 
      [41] "EMG 1"                        "EMG 2"                       
      [43] "EMG 3"                        "EMG 4"                       
      [45] "EMG 5"                        "EMG 6"                       
      [47] "EMG 7"                        "EMG 8"                       
      [49] "EMG 9"                        "EMG 10"                      
      [51] "EMG 11"                       "EMG 12"                      
      [53] "EMG 13"                       "EMG 14"                      
      [55] "EMG 15"                       "EMG 16"                      
      [57] "Sync"                         "Amti Gen 5 OR6-5-1000 3581_1"
      [59] "Amti Gen 5 OR6-5-1000 3581_2" "Amti Gen 5 OR6-5-1000 3581_3"
      [61] "Amti Gen 5 OR6-5-1000 3581_4" "Amti Gen 5 OR6-5-1000 3581_5"
      [63] "Amti Gen 5 OR6-5-1000 3581_6" "Amti Gen 5 OR6-5-1000 3582_1"
      [65] "Amti Gen 5 OR6-5-1000 3582_2" "Amti Gen 5 OR6-5-1000 3582_3"
      [67] "Amti Gen 5 OR6-5-1000 3582_4" "Amti Gen 5 OR6-5-1000 3582_5"
      [69] "Amti Gen 5 OR6-5-1000 3582_6"
      
      $ANALOG$GEN_SCALE
      [1] 1
      
      $ANALOG$SCALE
       [1]  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00
      [11]  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00
      [21]  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00
      [31]  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00
      [41]  1e-06  1e-06  1e-06  1e-06  1e-06  1e-06  1e-06  1e-06  1e-06  1e-06
      [51]  1e-06  1e-06  1e-06  1e-06  1e-06  1e-06  1e+00 -1e+00 -1e+00 -1e+00
      [61] -1e+00 -1e+00 -1e+00 -1e+00 -1e+00 -1e+00 -1e+00 -1e+00 -1e+00
      
      $ANALOG$OFFSET
       [1] 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
      [39] 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
      
      $ANALOG$UNITS
       [1] "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"  
      [13] "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"  
      [25] "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"  
      [37] "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"  
      [49] "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "N"   "N"   "N"  
      [61] "Nmm" "Nmm" "Nmm" "N"   "N"   "N"   "Nmm" "Nmm" "Nmm"
      
      $ANALOG$RATE
      [1] 2000
      
      $ANALOG$FORMAT
      character(0)
      
      $ANALOG$BITS
      integer(0)
      
      
      $SEG
      $SEG$PRED_ERROR
      [1] 30
      
      $SEG$MAX_RESID
      [1] 10
      
      $SEG$ACC_FACTOR
      [1] 50000
      
      $SEG$NOISE_FACTOR
      [1] 10
      
      $SEG$DATA_LIMITS
      [1] -605.91718 -124.87224    8.06986 2439.43213  526.84009 1496.37622
      
      
      $MANUFACTURER
      $MANUFACTURER$COMPANY
      [1] "Qualisys"
      
      $MANUFACTURER$SOFTWARE
      [1] "Qualisys Track Manager"
      
      $MANUFACTURER$VERSION
      [1]    2   17 3720
      
      
      $FORCE_PLATFORM
      $FORCE_PLATFORM$USED
      [1] 2
      
      $FORCE_PLATFORM$TYPE
      [1] 2 2
      
      $FORCE_PLATFORM$ZERO
      [1] 0 0
      
      $FORCE_PLATFORM$CORNERS
       [1]  508  464    0  508    0    0    0    0    0    0  464    0 1017  464    0
      [16] 1017    0    0  509    0    0  509  464    0
      
      $FORCE_PLATFORM$ORIGIN
      [1] -1.524  0.762 34.036 -1.016  0.000 36.322
      
      $FORCE_PLATFORM$CHANNEL
       [1] 58 59 60 61 62 63 64 65 66 67 68 69
      
      $FORCE_PLATFORM$CAL_MATRIX
       [1] 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
      [39] 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
      
      $FORCE_PLATFORM$MATRIX_STORE
      [1] "BYCOLUMN"
      
      
      $EVENT
      $EVENT$USED
      [1] 7
      
      $EVENT$LABELS
      [1] "LHS" "RTO" "RHS" "LTO" "LHS" "RTO" "RHS"
      
      $EVENT$TIMES
       [1] 0.000 3.590 0.000 3.685 0.000 4.050 0.000 4.160 0.000 4.535 0.000 4.650
      [13] 0.000 5.030
      
      
      $PROCESSING
      $PROCESSING$`Uncropped Measurement Length`
      [1] 8.155
      
      $PROCESSING$`Uncropped Measurement Frames`
      [1] 1631
      
      $PROCESSING$`Cropped Measurement Start Frame`
      [1] 705
      
      $PROCESSING$`Cropped Measurement End Frame`
      [1] 1044

==> c3dr_0.2.0.tar.gz: c3dr/tests/testthat/_snaps/read.md <==
# parameter import works

    Code
      d$parameters
    Output
      $POINT
      $POINT$USED
      [1] 55
      
      $POINT$SCALE
      [1] -0.07623225
      
      $POINT$RATE
      [1] 200
      
      $POINT$DATA_START
      [1] 29
      
      $POINT$FRAMES
      [1] 340
      
      $POINT$LABELS
       [1] "L_IAS"   "L_IPS"   "R_IPS"   "R_IAS"   "SNJ"     "SXS"     "TV8"    
       [8] "CV7"     "R_SCAP"  "L_HDF"   "L_HDB"   "R_HDB"   "R_HDF"   "L_FTC"  
      [15] "L_WAND1" "L_FLE"   "L_FME"   "L_FAX"   "L_TTC"   "L_WAND2" "L_FAL"  
      [22] "L_TAM"   "L_FCC"   "L_FM1"   "L_FM5"   "R_FTC"   "R_WAND1" "R_FLE"  
      [29] "R_FME"   "R_FAX"   "R_TTC"   "R_WAND2" "R_FAL"   "R_TAM"   "R_FCC"  
      [36] "R_FM1"   "R_FM5"   "L_HM5"   "L_HM2"   "L_UHE"   "L_RSP"   "L_WAND4"
      [43] "L_HLE"   "L_HME"   "L_WAND3" "R_HM5"   "R_HM2"   "R_UHE"   "R_RSP"  
      [50] "R_WAND4" "R_HLE"   "R_HME"   "R_WAND3" "L_SAJ"   "R_SAJ"  
      
      $POINT$DESCRIPTIONS
       [1] "L_IAS"   "L_IPS"   "R_IPS"   "R_IAS"   "SNJ"     "SXS"     "TV8"    
       [8] "CV7"     "R_SCAP"  "L_HDF"   "L_HDB"   "R_HDB"   "R_HDF"   "L_FTC"  
      [15] "L_WAND1" "L_FLE"   "L_FME"   "L_FAX"   "L_TTC"   "L_WAND2" "L_FAL"  
      [22] "L_TAM"   "L_FCC"   "L_FM1"   "L_FM5"   "R_FTC"   "R_WAND1" "R_FLE"  
      [29] "R_FME"   "R_FAX"   "R_TTC"   "R_WAND2" "R_FAL"   "R_TAM"   "R_FCC"  
      [36] "R_FM1"   "R_FM5"   "L_HM5"   "L_HM2"   "L_UHE"   "L_RSP"   "L_WAND4"
      [43] "L_HLE"   "L_HME"   "L_WAND3" "R_HM5"   "R_HM2"   "R_UHE"   "R_RSP"  
      [50] "R_WAND4" "R_HLE"   "R_HME"   "R_WAND3" "L_SAJ"   "R_SAJ"  
      
      $POINT$UNITS
      [1] "mm"
      
      $POINT$LONG_FRAMES
      [1] 340
      
      $POINT$Y_SCREEN
      [1] "-Z"
      
      $POINT$X_SCREEN
      [1] "-X"
      
      $POINT$ORIGINAL_LAST_FRAME
      [1] 1631
      
      
      $ANALOG
      $ANALOG$USED
      [1] 69
      
      $ANALOG$LABELS
       [1] "FP1_FX"                       "FP1_FY"                      
       [3] "FP1_FZ"                       "FP1_MX"                      
       [5] "FP1_MY"                       "FP1_MZ"                      
       [7] "Nothing"                      "Channel_08"                  
       [9] "Channel_09"                   "Channel_10"                  
      [11] "PF2-FX"                       "PF2-FY"                      
      [13] "PF2-FZ"                       "PF2-MX"                      
      [15] "PF2-MY"                       "PF2-MZ"                      
      [17] "Channel_17"                   "Channel_18"                  
      [19] "Channel_19"                   "Channel_20"                  
      [21] "Channel_21"                   "Channel_22"                  
      [23] "Channel_23"                   "Channel_24"                  
      [25] "Channel_25"                   "Channel_26"                  
      [27] "Channel_27"                   "Channel_28"                  
      [29] "Channel_29"                   "Channel_30"                  
      [31] "Channel_31"                   "Channel_32"                  
      [33] "TAPIS FZ1"                    "TAPIS FZ2"                   
      [35] "TAPIS FZ3"                    "TAPIS FZ4"                   
      [37] "TAPIS FY1+4"                  "TAPIS FY2+3"                 
      [39] "TAPIS FX1+2"                  "TAPIS FX3+4"                 
      [41] "EMG 1"                        "EMG 2"                       
      [43] "EMG 3"                        "EMG 4"                       
      [45] "EMG 5"                        "EMG 6"                       
      [47] "EMG 7"                        "EMG 8"                       
      [49] "EMG 9"                        "EMG 10"                      
      [51] "EMG 11"                       "EMG 12"                      
      [53] "EMG 13"                       "EMG 14"                      
      [55] "EMG 15"                       "EMG 16"                      
      [57] "Sync"                         "Amti Gen 5 OR6-5-1000 3581_1"
      [59] "Amti Gen 5 OR6-5-1000 3581_2" "Amti Gen 5 OR6-5-1000 3581_3"
      [61] "Amti Gen 5 OR6-5-1000 3581_4" "Amti Gen 5 OR6-5-1000 3581_5"
      [63] "Amti Gen 5 OR6-5-1000 3581_6" "Amti Gen 5 OR6-5-1000 3582_1"
      [65] "Amti Gen 5 OR6-5-1000 3582_2" "Amti Gen 5 OR6-5-1000 3582_3"
      [67] "Amti Gen 5 OR6-5-1000 3582_4" "Amti Gen 5 OR6-5-1000 3582_5"
      [69] "Amti Gen 5 OR6-5-1000 3582_6"
      
      $ANALOG$DESCRIPTIONS
       [1] "FP1_FX"                       "FP1_FY"                      
       [3] "FP1_FZ"                       "FP1_MX"                      
       [5] "FP1_MY"                       "FP1_MZ"                      
       [7] "Nothing"                      "Channel_08"                  
       [9] "Channel_09"                   "Channel_10"                  
      [11] "PF2-FX"                       "PF2-FY"                      
      [13] "PF2-FZ"                       "PF2-MX"                      
      [15] "PF2-MY"                       "PF2-MZ"                      
      [17] "Channel_17"                   "Channel_18"                  
      [19] "Channel_19"                   "Channel_20"                  
      [21] "Channel_21"                   "Channel_22"                  
      [23] "Channel_23"                   "Channel_24"                  
      [25] "Channel_25"                   "Channel_26"                  
      [27] "Channel_27"                   "Channel_28"                  
      [29] "Channel_29"                   "Channel_30"                  
      [31] "Channel_31"                   "Channel_32"                  
      [33] "TAPIS FZ1"                    "TAPIS FZ2"                   
      [35] "TAPIS FZ3"                    "TAPIS FZ4"                   
      [37] "TAPIS FY1+4"                  "TAPIS FY2+3"                 
      [39] "TAPIS FX1+2"                  "TAPIS FX3+4"                 
      [41] "EMG 1"                        "EMG 2"                       
      [43] "EMG 3"                        "EMG 4"                       
      [45] "EMG 5"                        "EMG 6"                       
      [47] "EMG 7"                        "EMG 8"                       
      [49] "EMG 9"                        "EMG 10"                      
      [51] "EMG 11"                       "EMG 12"                      
      [53] "EMG 13"                       "EMG 14"                      
      [55] "EMG 15"                       "EMG 16"                      
      [57] "Sync"                         "Amti Gen 5 OR6-5-1000 3581_1"
      [59] "Amti Gen 5 OR6-5-1000 3581_2" "Amti Gen 5 OR6-5-1000 3581_3"
      [61] "Amti Gen 5 OR6-5-1000 3581_4" "Amti Gen 5 OR6-5-1000 3581_5"
      [63] "Amti Gen 5 OR6-5-1000 3581_6" "Amti Gen 5 OR6-5-1000 3582_1"
      [65] "Amti Gen 5 OR6-5-1000 3582_2" "Amti Gen 5 OR6-5-1000 3582_3"
      [67] "Amti Gen 5 OR6-5-1000 3582_4" "Amti Gen 5 OR6-5-1000 3582_5"
      [69] "Amti Gen 5 OR6-5-1000 3582_6"
      
      $ANALOG$GEN_SCALE
      [1] 1
      
      $ANALOG$SCALE
       [1]  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00
      [11]  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00
      [21]  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00
      [31]  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00  1e+00
      [41]  1e-06  1e-06  1e-06  1e-06  1e-06  1e-06  1e-06  1e-06  1e-06  1e-06
      [51]  1e-06  1e-06  1e-06  1e-06  1e-06  1e-06  1e+00 -1e+00 -1e+00 -1e+00
      [61] -1e+00 -1e+00 -1e+00 -1e+00 -1e+00 -1e+00 -1e+00 -1e+00 -1e+00
      
      $ANALOG$OFFSET
       [1] 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
      [39] 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
      
      $ANALOG$UNITS
       [1] "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"  
      [13] "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"  
      [25] "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"  
      [37] "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"  
      [49] "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "V"   "N"   "N"   "N"  
      [61] "Nmm" "Nmm" "Nmm" "N"   "N"   "N"   "Nmm" "Nmm" "Nmm"
      
      $ANALOG$RATE
      [1] 2000
      
      $ANALOG$FORMAT
      character(0)
      
      $ANALOG$BITS
      integer(0)
      
      
      $SEG
      $SEG$PRED_ERROR
      [1] 30
      
      $SEG$MAX_RESID
      [1] 10
      
      $SEG$ACC_FACTOR
      [1] 50000
      
      $SEG$NOISE_FACTOR
      [1] 10
      
      $SEG$DATA_LIMITS
                [,1]       [,2]      [,3]
      [1,] -605.9172    8.06986  526.8401
      [2,] -124.8722 2439.43213 1496.3762
      
      
      $MANUFACTURER
      $MANUFACTURER$COMPANY
      [1] "Qualisys"
      
      $MANUFACTURER$SOFTWARE
      [1] "Qualisys Track Manager"
      
      $MANUFACTURER$VERSION
      [1]    2   17 3720
      
      
      $FORCE_PLATFORM
      $FORCE_PLATFORM$USED
      [1] 2
      
      $FORCE_PLATFORM$TYPE
      [1] 2 2
      
      $FORCE_PLATFORM$ZERO
      [1] 0 0
      
      $FORCE_PLATFORM$CORNERS
      $FORCE_PLATFORM$CORNERS[[1]]
           [,1] [,2] [,3] [,4]
      [1,]  508  508    0    0
      [2,]  464    0    0  464
      [3,]    0    0    0    0
      
      $FORCE_PLATFORM$CORNERS[[2]]
           [,1] [,2] [,3] [,4]
      [1,] 1017 1017  509  509
      [2,]  464    0    0  464
      [3,]    0    0    0    0
      
      
      $FORCE_PLATFORM$ORIGIN
             [,1]   [,2]
      [1,] -1.524 -1.016
      [2,]  0.762  0.000
      [3,] 34.036 36.322
      
      $FORCE_PLATFORM$CHANNEL
           [,1] [,2]
      [1,]   58   64
      [2,]   59   65
      [3,]   60   66
      [4,]   61   67
      [5,]   62   68
      [6,]   63   69
      
      $FORCE_PLATFORM$CAL_MATRIX
      $FORCE_PLATFORM$CAL_MATRIX[[1]]
           [,1] [,2] [,3] [,4] [,5] [,6]
      [1,]    0    0    0    0    0    0
      [2,]    0    0    0    0    0    0
      [3,]    0    0    0    0    0    0
      [4,]    0    0    0    0    0    0
      [5,]    0    0    0    0    0    0
      [6,]    0    0    0    0    0    0
      
      $FORCE_PLATFORM$CAL_MATRIX[[2]]
           [,1] [,2] [,3] [,4] [,5] [,6]
      [1,]    0    0    0    0    0    0
      [2,]    0    0    0    0    0    0
      [3,]    0    0    0    0    0    0
      [4,]    0    0    0    0    0    0
      [5,]    0    0    0    0    0    0
      [6,]    0    0    0    0    0    0
      
      
      $FORCE_PLATFORM$MATRIX_STORE
      [1] "BYCOLUMN"
      
      
      $EVENT
      $EVENT$USED
      [1] 7
      
      $EVENT$LABELS
      [1] "LHS" "RTO" "RHS" "LTO" "LHS" "RTO" "RHS"
      
      $EVENT$TIMES
           [,1]  [,2] [,3] [,4]  [,5] [,6] [,7]
      [1,] 0.00 0.000 0.00 0.00 0.000 0.00 0.00
      [2,] 3.59 3.685 4.05 4.16 4.535 4.65 5.03
      
      
      $PROCESSING
      $PROCESSING$`Uncropped Measurement Length`
      [1] 8.155
      
      $PROCESSING$`Uncropped Measurement Frames`
      [1] 1631
      
      $PROCESSING$`Cropped Measurement Start Frame`
      [1] 705
      
      $PROCESSING$`Cropped Measurement End Frame`
      [1] 1044
